# libpythonpro-lu
Módulo para exemplificar construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com um projeto de código aberto

Link do curso [PythonPro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.com/lutokozima/libpythonpro-lu.svg?branch=master)](https://travis-ci.com/lutokozima/libpythonpro-lu)
[![codecov](https://codecov.io/gh/lutokozima/libpythonpro-lu/branch/master/graph/badge.svg)](https://codecov.io/gh/lutokozima/libpythonpro-lu)

Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/scripts/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código
```console
flake8
```

Tópicos a serem abordados 
1. Git
2. Virtualenv
3. Pip